public inbox for development@lists.ipfire.org
 help / color / mirror / Atom feed
* [PATCH] Fixed some typos in network-functions.pl
@ 2015-09-20 11:49 Matthias Fischer
  2015-09-20 11:58 ` Michael Tremer
  0 siblings, 1 reply; 3+ messages in thread
From: Matthias Fischer @ 2015-09-20 11:49 UTC (permalink / raw)
  To: development

[-- Attachment #1: Type: text/plain, Size: 1332 bytes --]

"recognised" => "recognized"

Signed-off-by: Matthias Fischer <matthias.fischer(a)ipfire.org>
---
 config/cfgroot/network-functions.pl | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/config/cfgroot/network-functions.pl b/config/cfgroot/network-functions.pl
index cb4ca3d..c39b6d9 100644
--- a/config/cfgroot/network-functions.pl
+++ b/config/cfgroot/network-functions.pl
@@ -311,10 +311,10 @@ sub testsuite() {
 	my $address2 = &bin2ip($address1);
 	assert($address2 eq "8.8.8.8");
 
 	# Check if valid IP addresses are correctly recognised.
 	foreach my $address ("1.2.3.4", "192.168.180.1", "127.0.0.1") {
 		if (!&check_ip_address($address)) {
-			print "$address is not correctly recognised as a valid IP address!\n";
+			print "$address is not correctly recognized as a valid IP address!\n";
 			exit 1;
 		};
 	}
@@ -322,7 +322,7 @@ sub testsuite() {
 	# Check if invalid IP addresses are correctly found.
 	foreach my $address ("456.2.3.4", "192.768.180.1", "127.1", "1", "a.b.c.d", "1.2.3.4.5", "1.2.3.4/12") {
 		if (&check_ip_address($address)) {
-			print "$address is recognised as a valid IP address!\n";
+			print "$address is recognized as a valid IP address!\n";
 			exit 1;
 		};
 	}
@@ -311,10 +311,10 @@ sub testsuite() {
 	assert($address2 eq "8.8.8.8");
 
-	# Check if valid IP addresses are correctly recognised.
+	# Check if valid IP addresses are correctly recognized.
 	foreach my $address ("1.2.3.4", "192.168.180.1", "127.0.0.1") {
 		if (!&check_ip_address($address)) {
-- 
2.5.3


^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2015-09-20 12:44 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2015-09-20 11:49 [PATCH] Fixed some typos in network-functions.pl Matthias Fischer
2015-09-20 11:58 ` Michael Tremer
2015-09-20 12:44   ` Matthias Fischer

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox